#! /bin/bash
# File: compile_with_apptainer.sh
# Purpose: Build  container for the openCARP-Actors project.
# Author: Kyle Klenk, Joyce Reimer, Raymond Spiteri
# Date: 2023-12-05


###############################################
# Prerequisites
#  - Install apptainer
#  - Buld the apptainer container from the Apptainerfile.def
#     - sudo apptainer build openCARP.sif Apptainerfile.def 
#  - Once you have an openCARP.sif file, you are ready to run this script.
###############################################


###############################################
# Compiling openCARP with Apptainer

echo "Compiling openCARP with Apptainer..."
if [ -d "openCARP" ]; then
    echo "openCARP directory exists. Proceeding..."
    openCARP_dir="$(realpath $(pwd)/..)"
    apptainer exec --bind $openCARP_dir:/code/openCARP-Actors \
                   --pwd /code/openCARP-Actors/environment_setup/openCARP openCARP.sif \
                   /bin/bash -c 'cmake -S. -B_build -DDLOPEN=ON -DUSE_OPENMP=ON -DCMAKE_BUILD_TYPE=Release -DENABLE_ACTORS=ON && cmake --build _build -j'
else
    echo "openCARP directory does not exist!!"
    echo "Clone openCARP with the following command and checkout the develop branch:"
    echo "git clone https://git.cs.usask.ca/numerical_simulations_lab/cardiac/openCARP.git"
fi


